#
# spec file for package python-google-cloud-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-google-cloud-core
Version:        2.4.1
Release:        3.4
Summary:        Google Cloud API client core library
License:        Apache-2.0
URL:            https://github.com/googleapis/python-cloud-core
Source:         https://files.pythonhosted.org/packages/source/g/google-cloud-core/google-cloud-core-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module google-api-core >= 1.31.6}
BuildRequires:  %{python_module google-auth >= 1.25.0}
BuildRequires:  %{python_module grpcio >= 1.38.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-api-core >= 1.31.6
Requires:       python-google-auth >= 1.25.0
Recommends:     python-grpcio >= 1.38.0
BuildArch:      noarch
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-google-cloud-core < %{version}
%endif
%python_subpackages

%description
Core Helpers for Google Cloud Python Client Library
This library is not meant to stand-alone. Instead it defines
common helpers (e.g. base ``Client`` classes) used by all of the
``google-cloud-*`` packages.

%prep
%setup -q -n google-cloud-core-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTEST_ADDOPTS="--import-mode=importlib"
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/google/cloud
%{python_sitelib}/google_cloud_core-%{version}.dist-info

%changelog
* Tue Mar  5 2024 Robert Schweikert <rjschwei@suse.com>
- Obsolete Python 3.6 build for SLE 15 SP4 and openSUSE Leap 15.4 and later
* Mon Feb 26 2024 Robert Schweikert <rjschwei@suse.com>
- Version update in SLE 15 SP4 and later (jsc#PED-6697)
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.4.1:
  * Fix regression with `google.cloud._helpers._NOW` (#266)
  * Add support for Python 3.12 (#256)
  * Introduce compatibility with native namespace packages (#260)
- switch to new python stack for SLE15
* Tue Jul 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.3.3:
  * Update docs structure for c.g.c usage (#226)
* Thu Sep  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.3.2:
  * require python 3.7+ (#201)
- from version 2.3.1:
  * fix changelog header to consistent size (#194)
- Update BuildRequires and Requires from setup.py
* Sat Apr 16 2022 Matej Cepl <mcepl@suse.com>
- Update to 2.3.0:
  - allow extra_api_info to be passed to api request
  - deps: require google-api-core>=1.31.5, >=2.3.2
  - deps: require google-auth 1.25.0
  - correct param type of
    _ClientFactoryMixin.from_service_account_info method
  - correct Client and Connection type annotations
  - add mypy checking + 'py.typed' files
  - add support for Python 3.10
  - drop python 2.7 support
- We really don't need mock BR at all.
* Thu Sep 30 2021 Matej Cepl <mcepl@suse.com>
- Add --import-mode=importlib to make test suite work.
* Tue Aug  3 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.7.2:
  * pass kwargs through in 'from_service_account_json' (#109) (efc4bbf)
  * add 'Client.close' (#100) (7387fc8)
  * add 'Client.from_service_account_info' factory (#54) (7e59360)
- Actually use %%pytest macro for testing
* Tue Apr  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.6.0:
  * add mtls support
  * infer project from explicit service account creds
  * add support for Python 3.9, drop support for Python 3.5
  * require six>=1.12.0 and google-api-core>=1.21.
  * avoid using 'pkg_resources' to determine version
  * handle query_params tuples in JSONConnection.build_api_url
  * add quota_project, credentials file, and scopes options
  * add support for Python 3.8
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.3.0
  * Add timeout param to JSONConnection.api_request().
  * Change default api_request() timeout to non-None
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.3:
  * Make Client.build_api_url an instance method.
  * Prevent requests from hanging on SSL handshake
* Thu May 16 2019 kwu@suse.com
- Update to v1.0.0
  * Remove classifier for Python 3.4 for end-of-life. (#7535)
  * Refactor client_info support. (#7849)
  * Update dep on api_core >= 1.11.0. (#7986)
  * Updated client library documentation URLs. (#7307)
* Mon Feb 18 2019 John Vandenberg <jayvdb@gmail.com>
- Activate tests
- Increased minimum google-api-core >= 1.0.0 per upstream
- Update to v0.29.1
  * Document Python 2 deprecation
- from 0.29.0
  * Breaking Changes
  - Remove iam module from core. This module is now available as part of
    google-api-core.
  * Implementation Changes
  - Fix _time_from_iso8601_time_naive for values with micros.
  - Import stdlib ABCs from collections.abc rather than collections.
  * Dependencies
  - Bump minimum api_core version to 1.0.0.
  * Internal / Testing Changes
  - Blacken api_core and core.
  - Add / fix badges for PyPI / versions.
  - Use new Nox. (#6175)
  - Use inplace installs for nox
  - Fix bad trove classifier.
  - Add Test runs for Python 3.7 and remove 3.4
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue May 29 2018 tbechtold@suse.com
- Initial packaging (version 0.28.1)
